@@ -914,7 +914,7 @@ void BufferParams::writeFile(ostream & os) const
 		os << "\\begin_removed_modules" << '\n';
 		list<string>::const_iterator it = removed_modules_.begin();
 		list<string>::const_iterator en = removed_modules_.end();
-		for (; it != en; it++)
+		for (; it != en; ++it)
 			os << *it << '\n';
 		os << "\\end_removed_modules" << '\n';
 	}
@@ -924,7 +924,7 @@ void BufferParams::writeFile(ostream & os) const
 		os << "\\begin_modules" << '\n';
 		LayoutModuleList::const_iterator it = layout_modules_.begin();
 		LayoutModuleList::const_iterator en = layout_modules_.end();
-		for (; it != en; it++)
+		for (; it != en; ++it)
 			os << *it << '\n';
 		os << "\\end_modules" << '\n';
 	}
@@ -934,7 +934,7 @@ void BufferParams::writeFile(ostream & os) const
 		os << "\\begin_includeonly" << '\n';
 		list<string>::const_iterator it = included_children_.begin();
 		list<string>::const_iterator en = included_children_.end();
-		for (; it != en; it++)
+		for (; it != en; ++it)
 			os << *it << '\n';
 		os << "\\end_includeonly" << '\n';
 	}
@@ -1787,6 +1787,11 @@ bool BufferParams::writeLaTeX(otexstream & os, LaTeXFeatures & features,
 		// hyperref loads this automatically
 		lyxpreamble += "\\usepackage{nameref}\n";
 
+	// bibtopic needs to be loaded after hyperref.
+	// the dot provides the aux file naming which LyX can detect.
+	if (features.mustProvide("bibtopic"))
+		lyxpreamble += "\\usepackage[dot]{bibtopic}\n";
+
 	// Will be surrounded by \makeatletter and \makeatother when not empty
 	docstring atlyxpreamble;
 
@@ -2047,8 +2052,8 @@ bool BufferParams::addLayoutModule(string const & modName)
 {
 	LayoutModuleList::const_iterator it = layout_modules_.begin();
 	LayoutModuleList::const_iterator end = layout_modules_.end();
-	for (; it != end; it++)
-		if (*it == modName) 
+	for (; it != end; ++it)
+		if (*it == modName)
 			return false;
 	layout_modules_.push_back(modName);
 	return true;
@@ -2373,7 +2378,7 @@ void BufferParams::readRemovedModules(Lexer & lex)
 	// start of the read.
 	list<string>::const_iterator rit = removed_modules_.begin();
 	list<string>::const_iterator const ren = removed_modules_.end();
-	for (; rit != ren; rit++) {
+	for (; rit != ren; ++rit) {
 		LayoutModuleList::iterator const mit = layout_modules_.begin();
 		LayoutModuleList::iterator const men = layout_modules_.end();
 		LayoutModuleList::iterator found = find(mit, men, *rit);
