@@ -1036,9 +1036,17 @@ bool BufferView::getStatus(FuncRequest const & cmd, FuncStatus & flag)
 		// buffer clean/dirty status by itself.
 		flag.setEnabled(!buffer_.isReadonly() && buffer_.undo().hasRedoStack());
 		break;
-	case LFUN_FILE_INSERT:
 	case LFUN_FILE_INSERT_PLAINTEXT_PARA:
-	case LFUN_FILE_INSERT_PLAINTEXT:
+	case LFUN_FILE_INSERT_PLAINTEXT: {
+		docstring const fname = cmd.argument();
+		if (!FileName::isAbsolute(to_utf8(fname))) {
+			flag.message(_("Absolute filename expected."));
+			return false;
+		}
+		flag.setEnabled(cur.inTexted());
+		break;
+	}
+	case LFUN_FILE_INSERT:
 	case LFUN_BOOKMARK_SAVE:
 		// FIXME: Actually, these LFUNS should be moved to Text
 		flag.setEnabled(cur.inTexted());
@@ -1196,14 +1204,7 @@ void BufferView::editInset(string const & name, Inset * inset)
 
 void BufferView::dispatch(FuncRequest const & cmd, DispatchResult & dr)
 {
-	//lyxerr << [ cmd = " << cmd << "]" << endl;
-
-	// Make sure that the cached BufferView is correct.
-	LYXERR(Debug::ACTION, " action[" << cmd.action() << ']'
-		<< " arg[" << to_utf8(cmd.argument()) << ']'
-		<< " x[" << cmd.x() << ']'
-		<< " y[" << cmd.y() << ']'
-		<< " button[" << cmd.button() << ']');
+	LYXERR(Debug::ACTION, "BufferView::dispatch: cmd: " << cmd);
 
 	string const argument = to_utf8(cmd.argument());
 	Cursor & cur = d->cursor_;
@@ -1921,6 +1922,17 @@ void BufferView::dispatch(FuncRequest const & cmd, DispatchResult & dr)
 		break;
 	}
 
+	case LFUN_FILE_INSERT_PLAINTEXT_PARA:
+	case LFUN_FILE_INSERT_PLAINTEXT: {
+		bool const as_paragraph = (act == LFUN_FILE_INSERT_PLAINTEXT_PARA);
+		string const fname = to_utf8(cmd.argument());
+		if (!FileName::isAbsolute(fname))
+			dr.setMessage(_("Absolute filename expected."));
+		else
+			insertPlaintextFile(FileName(fname), as_paragraph);
+		break;
+	}
+
 	// FIXME We do not really want this here, but it has to be at present
 	// because we need a cursor for the recordUndoFullDocument call. What
 	// we would really like is a recordUndoBufferParams call that did not
@@ -2152,8 +2164,8 @@ void BufferView::mouseEventDispatch(FuncRequest const & cmd0)
 
 	// Notify left insets
 	if (cur != old) {
-		old.fixIfBroken();
-		bool badcursor = notifyCursorLeavesOrEnters(old, cur);
+		bool badcursor = old.fixIfBroken() | cur.fixIfBroken();
+		badcursor |= notifyCursorLeavesOrEnters(old, cur);
 		if (badcursor)
 			cursor().fixIfBroken();
 	}
