@@ -135,7 +135,7 @@ public:
 		current_change_number_ = 0;
 	}
 
-	void setRange(FontSpan const fp, SpellChecker::Result state)
+	void setRange(FontSpan const & fp, SpellChecker::Result state)
 	{
 		Ranges result;
 		RangesIterator et = ranges_.end();
@@ -1395,7 +1395,7 @@ void Paragraph::Private::validate(LaTeXFeatures & features) const
 
 	if (features.runparams().flavor == OutputParams::HTML
 	    && layout_->htmltitle()) {
-		features.setHTMLTitle(owner_->asString(AS_STR_INSETS));
+		features.setHTMLTitle(owner_->asString(AS_STR_INSETS | AS_STR_SKIPDELETE));
 	}
 
 	// check the params.
