@@ -243,11 +243,13 @@ Font const Text::outerFont(pit_type par_offset) const
 {
 	depth_type par_depth = pars_[par_offset].getDepth();
 	FontInfo tmpfont = inherit_font;
-
+	depth_type prev_par_depth = 0;
 	// Resolve against environment font information
 	while (par_offset != pit_type(pars_.size())
+	       && par_depth != prev_par_depth
 	       && par_depth
 	       && !tmpfont.resolved()) {
+		prev_par_depth = par_depth;
 		par_offset = outerHook(par_offset);
 		if (par_offset != pit_type(pars_.size())) {
 			tmpfont.realize(pars_[par_offset].layout().font);
@@ -1666,7 +1668,7 @@ bool Text::dissolveInset(Cursor & cur)
 		// change it to the buffer language.
 		ParagraphList::iterator it = plist.begin();
 		ParagraphList::iterator it_end = plist.end();
-		for (; it != it_end; it++)
+		for (; it != it_end; ++it)
 			it->changeLanguage(b.params(), latex_language, b.language());
 
 		pasteParagraphList(cur, plist, b.params().documentClassPtr(),
