@@ -702,6 +702,8 @@ int TextMetrics::labelFill(pit_type const pit, Row const & row) const
 }
 
 
+#if 0
+// Not used, see TextMetrics::rowBreakPoint. 
 // this needs special handling - only newlines count as a break point
 static pos_type addressBreakPoint(pos_type i, Paragraph const & par)
 {
@@ -713,6 +715,7 @@ static pos_type addressBreakPoint(pos_type i, Paragraph const & par)
 
 	return end;
 }
+#endif
 
 
 int TextMetrics::labelEnd(pit_type const pit) const
@@ -793,8 +796,13 @@ pos_type TextMetrics::rowBreakPoint(int width, pit_type const pit,
 
 	Layout const & layout = par.layout();
 
+#if 0
+	//FIXME: As long as leftMargin() is not correctly implemented for 
+	// MARGIN_RIGHT_ADDRESS_BOX, we should also not do this here.
+	// Otherwise, long rows will be painted off the screen.
 	if (layout.margintype == MARGIN_RIGHT_ADDRESS_BOX)
 		return addressBreakPoint(pos, par);
+#endif
 
 	pos_type const body_pos = par.beginOfBody();
 
@@ -1230,8 +1238,9 @@ pos_type TextMetrics::getColumnNearX(pit_type const pit,
 
 	// if the first character is a separator, and we are in RTL
 	// text, this character will not be painted on screen
-	// and thus we should not count it and skip to the next.
-	if (rtl && par.isSeparator(bidi.vis2log(vc)))
+	// and thus we should not count it and skip to the next. Only
+	// in freespacing paragraphs, this first character is painted.
+	if (!par.isFreeSpacing() && par.isSeparator(bidi.vis2log(vc)))
 		++vc;
 
 	while (vc < end && tmpx <= x) {
@@ -1375,7 +1384,8 @@ pit_type TextMetrics::getPitNearY(int y)
 	int yy = -1;
 	ParMetricsCache::const_iterator it = par_metrics_.begin();
 	ParMetricsCache::const_iterator et = par_metrics_.end();
-	ParMetricsCache::const_iterator last = et; last--;
+	ParMetricsCache::const_iterator last = et;
+	--last;
 
 	ParagraphMetrics const & pm = it->second;
 
