@@ -1369,8 +1369,8 @@ bool GuiWorkArea::isFullScreen()
 
 EmbeddedWorkArea::EmbeddedWorkArea(QWidget * w): GuiWorkArea(w)
 {
-	buffer_ = theBufferList().newBuffer(
-		support::FileName::tempName().absFileName() + "_embedded.internal");
+	buffer_ = theBufferList().newInternalBuffer(
+		support::FileName::tempName("embedded.internal").absFileName());
 	buffer_->setUnnamed(true);
 	buffer_->setFullyLoaded(true);
 	setBuffer(*buffer_);
