@@ -57,7 +57,7 @@ namespace os = support::os;
 InsetBibtex::InsetBibtex(Buffer * buf, InsetCommandParams const & p)
 	: InsetCommand(buf, p)
 {
-	buffer().invalidateBibinfoCache();
+	buffer().invalidateBibfileCache();
 }
 
 
@@ -952,7 +952,7 @@ docstring InsetBibtex::xhtml(XHTMLStream & xs, OutputParams const &) const
 		xs << html::StartTag("div", "class='bibtexentry'");
 		// FIXME XHTML
 		// The same name/id problem we have elsewhere.
-		string const attr = "id='" + to_utf8(entry.key()) + "'";
+		string const attr = "id='LyXCite-" + to_utf8(entry.key()) + "'";
 		xs << html::CompTag("a", attr);
 		docstring citekey;
 		if (numbers)
