@@ -34,6 +34,7 @@
 #include "LyXRC.h"
 #include "Lexer.h"
 #include "MetricsInfo.h"
+#include "output_plaintext.h"
 #include "output_xhtml.h"
 #include "OutputParams.h"
 #include "TextClass.h"
@@ -618,7 +619,7 @@ void InsetInclude::latex(otexstream & os, OutputParams const & runparams) const
 		runparams.par_begin = 0;
 		runparams.par_end = tmp->paragraphs().size();
 		if (!tmp->makeLaTeXFile(tmpwritefile, masterFileName(buffer()).
-				onlyPath().absFileName(), runparams, false)) {
+				onlyPath().absFileName(), runparams, Buffer::OnlyBody)) {
 			docstring msg = bformat(_("Included file `%1$s' "
 					"was not exported correctly.\nWarning: "
 					"LaTeX export is probably incomplete."),
@@ -785,7 +786,7 @@ docstring InsetInclude::xhtml(XHTMLStream & xs, OutputParams const & rp) const
 	if (all_pars) {
 		op.par_begin = 0;
 		op.par_end = 0;
-		ibuf->writeLyXHTMLSource(xs.os(), op, true);
+		ibuf->writeLyXHTMLSource(xs.os(), op, Buffer::IncludedFile);
 	} else
 		xs << XHTMLStream::ESCAPE_NONE 
 		   << "<!-- Included file: " 
@@ -796,7 +797,7 @@ docstring InsetInclude::xhtml(XHTMLStream & xs, OutputParams const & rp) const
 }
 
 
-int InsetInclude::plaintext(odocstream & os, OutputParams const &) const
+int InsetInclude::plaintext(odocstream & os, OutputParams const & op) const
 {
 	if (isVerbatim(params()) || isListings(params())) {
 		os << '[' << screenLabel() << '\n';
@@ -804,11 +805,16 @@ int InsetInclude::plaintext(odocstream & os, OutputParams const &) const
 		os << includedFileName(buffer(), params()).fileContents("UTF-8");
 		os << "\n]";
 		return PLAINTEXT_NEWLINE + 1; // one char on a separate line
-	} else {
+	}
+
+	Buffer const * const ibuf = loadIfNeeded();
+	if (!ibuf) {
 		docstring const str = '[' + screenLabel() + ']';
 		os << str;
 		return str.size();
 	}
+	writePlaintextFile(*ibuf, os, op);
+	return 0;
 }
 
 
@@ -849,7 +855,7 @@ int InsetInclude::docbook(odocstream & os, OutputParams const & runparams) const
 		LYXERR(Debug::LATEX, "exportfile:" << exportfile);
 		LYXERR(Debug::LATEX, "writefile:" << writefile);
 
-		tmp->makeDocBookFile(writefile, runparams, true);
+		tmp->makeDocBookFile(writefile, runparams, Buffer::OnlyBody);
 	}
 
 	runparams.exportdata->addExternalFile("docbook", writefile,
