@@ -143,7 +143,7 @@ const char * const known_paper_sizes[] = { "a0paper", "b0paper", "c0paper",
 const char * const known_class_paper_sizes[] = { "a4paper", "a5paper",
 "executivepaper", "legalpaper", "letterpaper", 0};
 
-const char * const known_paper_margins[] = { "lmargin", "tmargin", "rmargin", 
+const char * const known_paper_margins[] = { "lmargin", "tmargin", "rmargin",
 "bmargin", "headheight", "headsep", "footskip", "columnsep", 0};
 
 const char * const known_coded_paper_margins[] = { "leftmargin", "topmargin",
@@ -332,7 +332,7 @@ Author const & Preamble::getAuthor(std::string const & name) const
 {
 	Author author(from_utf8(name), empty_docstring());
 	for (AuthorList::Authors::const_iterator it = authors_.begin();
-	     it != authors_.end(); it++)
+	     it != authors_.end(); ++it)
 		if (*it == author)
 			return *it;
 	static Author const dummy;
@@ -388,7 +388,7 @@ string remove_braces(string const & value)
 } // anonymous namespace
 
 
-Preamble::Preamble() : one_language(true)
+Preamble::Preamble() : one_language(true), title_layout_found(false)
 {
 	//h_backgroundcolor;
 	//h_boxbgcolor;
@@ -401,6 +401,7 @@ Preamble::Preamble() : one_language(true)
 	h_font_sans               = "default";
 	h_font_typewriter         = "default";
 	h_font_default_family     = "default";
+	h_use_non_tex_fonts       = "false";
 	h_font_sc                 = "false";
 	h_font_osf                = "false";
 	h_font_sf_scale           = "100";
@@ -581,8 +582,12 @@ void Preamble::handle_package(Parser &p, string const & name,
 	add_package(name, options);
 	string scale;
 
-	if (is_known(name, known_xetex_packages))
+	if (is_known(name, known_xetex_packages)) {
 		xetex = true;
+		h_use_non_tex_fonts = "true";
+		if (h_inputencoding == "auto")
+			p.setEncoding("utf8");
+	}
 
 	// roman fonts
 	if (is_known(name, known_roman_fonts)) {
@@ -672,7 +677,7 @@ void Preamble::handle_package(Parser &p, string const & name,
 			delete_opt(options, known_languages);
 		}
 		else
-			h_preamble << "\\usepackage{babel}\n";						
+			h_preamble << "\\usepackage{babel}\n";
 	}
 
 	else if (name == "fontenc") {
@@ -733,6 +738,8 @@ void Preamble::handle_package(Parser &p, string const & name,
 		     name == "multirow" || name == "nomencl" || name == "setspace" ||
 		     name == "splitidx" || name == "subscript" || name == "ulem" ||
 		     name == "url") {
+		if (name == "splitidx")
+			h_use_indices = "true";
 		if (!in_lyx_preamble)
 			h_preamble << package_beg_sep << name
 			           << package_mid_sep << "\\usepackage{"
@@ -889,7 +896,7 @@ bool Preamble::writeLyXHeader(ostream & os, bool subdoc)
 		os << "\\begin_modules\n";
 		vector<string>::const_iterator const end = used_modules.end();
 		vector<string>::const_iterator it = used_modules.begin();
-		for (; it != end; it++)
+		for (; it != end; ++it)
 			os << *it << '\n';
 		os << "\\end_modules\n";
 	}
@@ -901,6 +908,7 @@ bool Preamble::writeLyXHeader(ostream & os, bool subdoc)
 	   << "\\font_sans " << h_font_sans << "\n"
 	   << "\\font_typewriter " << h_font_typewriter << "\n"
 	   << "\\font_default_family " << h_font_default_family << "\n"
+	   << "\\use_non_tex_fonts " << h_use_non_tex_fonts << "\n"
 	   << "\\font_sc " << h_font_sc << "\n"
 	   << "\\font_osf " << h_font_osf << "\n"
 	   << "\\font_sf_scale " << h_font_sf_scale << "\n"
@@ -1261,8 +1269,12 @@ void Preamble::parse(Parser & p, string const & forceclass,
 
 		else if (t.cs() == "def") {
 			string name = p.get_token().cs();
+			// In fact, name may be more than the name:
+			// In the test case of bug 8116
+			// name == "csname SF@gobble@opt \endcsname".
+			// Therefore, we need to use asInput() instead of cs().
 			while (p.next_token().cat() != catBegin)
-				name += p.get_token().cs();
+				name += p.get_token().asInput();
 			if (!in_lyx_preamble)
 				h_preamble << "\\def\\" << name << '{'
 					   << p.verbatim_item() << "}";
